SettingsCtxExt

Trait SettingsCtxExt 

pub trait SettingsCtxExt {
    // Required methods
    fn editor_search(&self) -> ContextVar<Txt>;
    fn editor_selected_category(&self) -> ContextVar<CategoryId>;
    fn editor_state(&self) -> Var<Option<SettingsEditorState>>;
    fn editor_setting(&self) -> Var<Option<Setting>>;
}
Extends SETTINGS to provide contextual information in an editor.

Required Methods

Gets a read-write context var that tracks the search text.

fn editor_selected_category(&self) -> ContextVar<CategoryId>

Gets a read-write context var that tracks the selected category.

fn editor_state(&self) -> Var<Option<SettingsEditorState>>

Gets a read-only context var that tracks the current editor data state.

fn editor_setting(&self) -> Var<Option<Setting>>

Gets a read-only context var that tracks the Setting entry the widget is inside, or will be.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl SettingsCtxExt for SETTINGS

Implementors