pub trait WidgetInfoSettingExt {
// Required method
fn setting_key(&self) -> Option<ConfigKey>;
}Expand description
Extends WidgetInfo to provide the setting config key for setting widgets.
Required Methods
Sourcefn setting_key(&self) -> Option<ConfigKey>
fn setting_key(&self) -> Option<ConfigKey>
Gets the setting config key, if this widget represents a setting item.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".